@@ -130,6 +130,25 @@ class TestSourceModel(unittest.TestCase):
         service.subscriber_identifier = 123
         self.assertEqual(service.subscriber_identifier, "123")
 
+    def test_service_url(self):
+        """Test field checking of service.url"""
+        service = Service("s1", url=None)
+        self.assertEqual(service.url, None)
+        service = Service("s1", url="")  # url can't be empty string
+        self.assertError(service, 'url', "")
+        self.assertEqual(service.url, None)
+        service = Service("s1")
+        self.assertEqual(service.url, None)
+        service.url = "https://my.url.com"
+        self.assertEqual(service.url, "https://my.url.com")
+        service = Service("s1", url="https://my.url.com")
+        self.assertEqual(service.url, "https://my.url.com")
+        service.url = "https://url2.net"
+        self.assertEqual(service.url, "https://url2.net")
+        service.url = 0
+        self.assertError(service, 'url', 0)
+        self.assertEqual(service.url, "https://url2.net")
+
     def test_service_attachment(self):
         """Test field checking of service.attachment"""
         service = Service("s1")
